Cheetah.TemplateCmdLineIface module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.TemplateCmdLineIface module

class `Cheetah.TemplateCmdLineIface.` `CmdLineIface`(templateObj, scriptName='sphinx-build', cmdLineArgs=['-b', 'html', '-d', '_build/doctrees', '.', '_build/html'])

  Bases: `object`

  A command line interface to compiled Cheetah template modules.

  `run`()

    The main program controller.

  `usage`()

exception `Cheetah.TemplateCmdLineIface.` `Error`

  Bases: `Exception`